


clear all

addpath('/data/aces/aces1/yonghe/gretna')

%**************************************************************************
%  calculate local and global efficiency of structural cortical 
%  networks using cortical thickness measurements (group 1)
%**************************************************************************

%read cortical thickness files of each subject
input_Group1_ct_left = 'Group1_subject_filename_ct_left.txt';
input_Group1_ct_right = 'Group1_subject_filename_ct_right.txt';
[M_left, M_right] = gretna_readthickness(input_Group1_ct_left,   input_Group1_ct_right);

%read ANIMAL (cortical parcellation) files of each subject
input_Group1_ANIMAL_left = 'Group1_subject_filename_ANIMAL_Labels_left.txt';
input_Group1_ANIMAL_right = 'Group1_subject_filename_ANIMAL_Labels_right.txt';
[vertex_label_left, vertex_label_right] = gretna_surfaceseg(input_Group1_ANIMAL_left, input_Group1_ANIMAL_right);
% if you want to visulize the ANIMAL parcellation using brain-view
% software, please try....
% csvwrite('vertex_label_left.txt', vertex_label_left)
% csvwrite('vertex_label_right.txt', vertex_label_right)
% brain-view vertex_label_left.txt XXXXXX_mid_surface_left_81920.obj
% brain-view vertex_label_right.txt XXXXXX_mid_surface_left_81920.obj

%raw regional cortical thickness values for reach subject
[regional_thickness] = gretna_regionalthickness (M_left, vertex_label_left, M_right, vertex_label_right);

% removing no interest covariates (e.g. age, gender or mean overall
% thickness) using regression analysis. The resulting residuals can be used
% to substitute for raw regional thickness values. Here we just removed
% mean overall thickness. If you want to remove the effects of age and
% gender, please change Group1_cov_1. It should be like this: 
% cov = [gender age gender-age averageoverll_thickness]; 
% age: n*1; gender: n*1; (n: the number of subjects)
% Group_cov = [mean(regional_thickness,2) age gender];

cov = [mean(regional_thickness,2)];
[regional_thickness_resid1] = gretna_rawtoresid(regional_thickness, cov);


%**************************************************************************
%  calculate local and global efficiency of structural cortical 
%  networks using cortical thickness measurements (group 2)
%**************************************************************************
%
%          Repeat the steps of Group1 above
% 
% *************************************************************************
%................................
%.............................
[regional_thickness_resid2] = gretna_rawtoresid(regional_thickness2, cov2);


% if you want to calucate efficiency differences between two groups at a specific cost
% of 0.1 (you can select other specfic cost [0 1]), please run: 
s1 = 0.1; s2 = 0.1; deltas=0.2; num_rand = 1000;
[Sparsity_ad_norm, Eff_specific_ad_norm] = gretna_effdiff_sparsity (residuals_ad, residuals_norm, s1, s2, deltas, num_rand);

% if you want to calucate efficiency differences between two groups at a wide range of cost
% of 0.1~0.4 at an interval of 0.01, pealse run: 
s1 = 0.05; s2 = 0.4; deltas=0.025; num_rand = 500;
%[Sparsity, Eff_range] = gretna_effdiff_sparsity (regional_thickness_resid1, regional_thickness_resid2, s1, s2, deltas, num_rand);
[Sparsity_ad_norm, Eff_specific_ad_norm] = gretna_effdiff_sparsity (residuals_ad, residuals_norm, s1, s2, deltas, num_rand);



% look at the results of Eff_specific or Eff_range



