
% Example: Between-group small-world analysis using cortical thickness
% measurements. Yong HE, BIC, MNI, 05/25/2007

%***********************************************************
% enter matlab window

mkdir /data/aces/aces1/yonghe/test
cd /data/aces/aces1/yonghe/test
matlab -nodisplay
 
% *********************************************************



 
 
clear all
warning off

%--------------------------------------------------------------------------
% add the gretna functions into the search path.
addpath('/data/aces/aces1/yonghe/gretna')
load labels.txt

%--------------------------------------------------------------------------
% set the cortical thickness files (e.g. native and 30 smooth kernal)
isnative = 1; % 1: native;

% fwhm=0.0;no smmoth; if fwhm=10, indicating 10 mm smooth kernal; 
%Please examine your thickness file to determine the fwhm;
fwhm = 0.0;


%--------------------------------------------------------------------------
%set your directory of cortical thickness files (set them by yourself !!)
%Group1:
% First, you should establish a subID1 file that includes ID number of each
% subject in this group. Look at the example of subID1 file
% /data/aces/aces1/yonghe/gretna/subID1
 
normal_sourcedir =   '/data/cortfmri/cortfmri1/jens/najma/CIVET_JAN2007_young_lsq12/PROCESSED_SUBJECTS/';
normal_IDfile ='/data/aces/aces1/yonghe/naj2/list_id_young.txt';
normal_thicknessdir = '/thickness/';
normal_surfacedir = '/segment/';
normal_prefix = 'pbi_TMCT';



%Group2
% First, you should establish a subID2 file that includes ID number of each
% subject in this group. Look at the example of subID1 file
% /data/aces/aces1/yonghe/gretna/subID1

patient_sourcedir = '/data/cortfmri/cortfmri1/jens/najma/CIVET_JAN2007_old_lsq12/PROCESSED_SUBJECTS/';
patient_IDfile ='/data/aces/aces1/yonghe/naj2/list_id_old.txt';
patient_thicknessdir = '/thickness/';
patient_surfacedir = '/segment/';
patient_prefix = 'SE2005';


%--------------------------------------------------------------------------
%read the cortical thickness files of each subject
[normal_vertex_ct_matrix_left,normal_vertex_ct_matrix_right] = gretna_readthickness2(normal_sourcedir, normal_IDfile, normal_thicknessdir, normal_prefix, isnative, fwhm);
[patient_vertex_ct_matrix_left,patient_vertex_ct_matrix_right] = gretna_readthickness2(patient_sourcedir, patient_IDfile, patient_thicknessdir, patient_prefix, isnative, fwhm);

%read the ANIMAL (cortical parcellation) files of each subject
%obtain the vertex labels of the left and right hemisphere (Fig.1 B)
[normal_animal_matrix_left,normal_animal_matrix_right] = gretna_readanimalmidsurf2(normal_sourcedir, normal_IDfile, normal_surfacedir, normal_prefix);
[patient_animal_matrix_left,patient_animal_matrix_right] = gretna_readanimalmidsurf2(patient_sourcedir, patient_IDfile, patient_surfacedir, patient_prefix);
[vertex_label_left, vertex_label_right]= gretna_surfaceseg ([normal_animal_matrix_left;patient_animal_matrix_left],[normal_animal_matrix_right; patient_animal_matrix_right]);
 
%raw regional cortical thickness values for reach subject
[normal_regional_thickness] = gretna_regionalthickness (normal_vertex_ct_matrix_left, vertex_label_left, normal_vertex_ct_matrix_right, vertex_label_right);
[patient_regional_thickness] = gretna_regionalthickness (patient_vertex_ct_matrix_left, vertex_label_left, patient_vertex_ct_matrix_right, vertex_label_right);
 

save young_old_regional_thickness_regardlessofHILOW.mat normal_regional_thickness patient_regional_thickness 
csvwrite('vertex_label_left.txt', vertex_label_left)
csvwrite('vertex_label_right.txt', vertex_label_right)
 
%please examine the label file (parcellation result) using brain-view
% brain-view subj_001_mid_surface_left_81920.obj vertex_label_left.txt
% brain-view subj_001_mid_surface_right_81920.obj vertex_label_right.txt
 
 
 labels = {'SFG.R','SFG.L','MFG.R','MFG.L','IFG.R','IFG.L','MdFG.R','MdFG.L','PrCG.R','PrCG.L','LOFG.R','LOFG.L','MOFG.R','MOFG.L','SPL.R','SPL.L',...
   'SMG.R','SMG.L','ANG.R','ANG.L','PCU.R','PCU.L','PoCG.R','PoCG.L','STG.R','STG.L','MTG.R','MTG.L','ITG.R','ITG.L','UNC.R','UNC.L','MOTG.R','MOTG.L',...
  'LOTG.R','LOTG.L','PHG.R','PHG.L','OP.R','OP.L','SOG.R','SOG.L','MOG.R','MOG.L','IOG.R','IOG.L','CUN.R','CUN.L','LING.R','LING.L','CING.R','CING.L','INS.R','INS.L'}';

 
 
 clear all


% -------------------------------------------------------------------------
% 1. calculating small-world properties for each group
% -------------------------------------------------------------------------
% removing no interest covariates (e.g. age, gender or mean overall
% thickness) using regression analysis. The resulting residuals can be used
% to substitute for raw regional thickness values. Here we just removed
% mean overall thickness. If you want to remove the effects of age and gender,
% please change Group1_cov_1 and Group2_cov_2. It should be like this:
%Group1_cov = [gender age gender-age averageoverll_thickness];


load young_old_regional_thickness_regardlessofHILOW.mat

Group1_reg_ct = normal_regional_thickness;
Group2_reg_ct = patient_regional_thickness;
Group1_averageoverll_ct = mean(Group1_reg_ct,2);
Group2_averageoverll_ct = mean(Group2_reg_ct,2);


% age: n1*1; gender: n1*1;
% Group1_cov = [Group1_averageoverll_ct age gender]; 
Group1_cov = [Group1_averageoverll_ct]; 
Group2_cov = [Group2_averageoverll_ct];
[Group1_reg_ct_resid] = gretna_rawtoresid(Group1_reg_ct, Group1_cov);
[Group2_reg_ct_resid] = gretna_rawtoresid(Group2_reg_ct, Group2_cov);
 

%sw: both of the two networks over a range of sparisty [5%-40%]
s1 = 0.05; s2 = 0.40; deltas = 0.01;
myspar = s1:deltas:s2
for i =1:length(myspar)
    i
    [bmatrix1,r] = gretna_R2b(corrcoef(Group1_reg_ct_resid), 's',myspar(i));
    [N, K, aveden, degree, sw1] = gretna_sw_harmonic(bmatrix1,1,100);
    [bmatrix2,r] = gretna_R2b(corrcoef(Group2_reg_ct_resid), 's',myspar(i));
    [N, K, aveden, degree, sw2] = gretna_sw_harmonic(bmatrix2,1,100);
    Gamma1(i) = sw1.Gamma;    Gamma2(i) = sw2.Gamma;
    Lambda1(i) = sw1.Lambda;    Lambda2(i) = sw2.Lambda;
    Sigma1(i) = sw1.Sigma;    Sigma2(i) = sw2.Sigma;
end
myspar = myspar*100;

subplot(1,2,1)
plot(myspar,Gamma1,'g',myspar,Lambda1,'r')
hold on; plot([myspar(1) myspar(1)], [0, 5.5],'k')
xlabel('Sparsity (%)'); 
text(myspar(1),0.6,'\rightarrow','HorizontalAlignment','left', 'color','k','FontSize',15)
axis([0 45 0 5.5])
subplot(1,2,2)
plot(myspar,Gamma2,'g',myspar,Lambda2,'r')
hold on; plot([myspar(1) myspar(1)], [0, 5.5],'k')
xlabel('Sparsity (%)'); 
text(myspar(1),0.6,'\rightarrow','HorizontalAlignment','left', 'color','k','FontSize',15)
axis([0 45 0 6.5])



% -------------------------------------------------------------------------
% 2. calculating between-group differences in the network properties (Cp,Lp)
%     using a randomized permutation procedure
% -------------------------------------------------------------------------
Num_permu = 400;
[Sparsity, PathLen, ClustCoff, Sigma] = ...
    gretna_swdiff_sparsity (Group1_reg_ct_resid, Group2_reg_ct_resid, s1, s2, deltas, Num_permu, 0);
myspar = Sparsity*100;
 


% plot the Cp and Lp
subplot(2,1,1)
hold on;
plot(myspar, ClustCoff.Cp.Cp1,'b',myspar, ClustCoff.Cp.Cp2,'r')
xlabel('Sparsity (%)');ylabel('Cp')
axis([3 43 0.1 0.6])

subplot(2,1,2) %Lp
hold on;
plot(myspar, PathLen.Lp.Lp1,'b',myspar, PathLen.Lp.Lp2,'r')
xlabel('Sparsity (%)');ylabel('Lp')
axis([3 43 1 6])



% plot the differences in Cp and Lp
subplot(2,1,1)
deltaCp = ClustCoff.Cp.Cp1-ClustCoff.Cp.Cp2;
hold on;
plot(myspar, ClustCoff.Cp.upper95Cp12diff,'k',myspar, ClustCoff.Cp.lower95Cp12diff,'k', 'Color',[0.6 0.6 0.6]);
xlabel('Sparsity (%)');ylabel('\DeltaCp')
for i = 1:length(myspar)
    if abs(ClustCoff.Cp.Cp12_diff_p (i))<=0.05
        text(myspar(i), deltaCp(i)-0.03,'\uparrow','HorizontalAlignment','center', 'color','k','FontSize',4)
    end
end
plot(myspar, deltaCp,'-ro','MarkerSize',2,'MarkerEdgeColor','r', 'MarkerFaceColor','r')
plot(myspar, ClustCoff.Cp.rerand_Cp12diff_mean,'-ko', 'MarkerSize',2, 'Color',[0.6 0.6 0.6])
axis([3 43 -0.2 0.5])

subplot(2,1,2) %Lp
deltaLp = PathLen.Lp.Lp1-PathLen.Lp.Lp2;
hold on;
plot(myspar, PathLen.Lp.upper95Lp12diff,'k',myspar, PathLen.Lp.lower95Lp12diff,'k','Color',[0.6 0.6 0.6]);
xlabel('Sparsity (%)');ylabel('\DeltaLp')
for i = 1:length(myspar)
    if abs(PathLen.Lp.Lp12_diff_p(i))<=0.05
        text(myspar(i),deltaLp(i)-0.18,'\uparrow','HorizontalAlignment','center', 'color','k','FontSize',4)
    end
end
plot(myspar, deltaLp,'-ro','MarkerSize',2,'MarkerEdgeColor','r', 'MarkerFaceColor','r')
plot(myspar, PathLen.Lp.rerand_Lp12diff_mean,'-ko', 'MarkerSize',2,'Color',[0.6 0.6 0.6])
axis([3 43 -2 2])





%please save the above results.
save sw_all.mat
