


clear all

addpath('/data/aces/aces1/yonghe/gretna')

%**************************************************************************
%  calculate local and global efficiency of structural cortical 
%  networks using volume measurements (group 1)
%**************************************************************************

%read regional gray matter volume and total brain tissue volume (Gray matter + White
%matter) files of each subject (from ANIMAL+INSECT) 
input_Group1_volume = 'Group1_subject_filename_ANIMAL_volume_masked.txt';
input_Group1_tissue = 'Group1_subject_filename_tissue.txt';
[reg_volume, tissue] = gretna_readvolume(input_Group1_volume,input_Group1_tissue);
 

% removing no interest covariates (e.g. age, gender or mean overall
% thickness) using regression analysis. The resulting residuals can be used
% to substitute for raw regional volume values. Here we just removed
% mean overall volume (tissue). If you want to remove the effects of age and
% gender, please change Group1_cov_1. It should be like this: 
% cov = [gender age gender-age tissue]; 
% age: n*1; gender: n*1; (n: the number of subjects)
% Group_cov = [tissue age gender];

cov = [tissue];
[reg_volume_resid] = gretna_rawtoresid(reg_volume, cov);

% calculating pearson correlation matrix
Rmatrix = corrcoef(reg_volume_resid);

% thresholding the correlation matrix into a binarized matrix at a sparsity
% (i.e. wiring cost) of 0.1 (you can choose a sparsity of 0.05~0.5)
sparsity = 0.1;
[bmatrix,r] = gretna_R2b(Rmatrix, 's', sparsity);

% small-world parameters (Cp,Lp, Gamma, Lambda, Sigma) in the network with
% a sparsity (i.e. cost) of 0.1. 
[N, K, degree, sw] = gretna_sw_harmonic(bmatrix); %look at the output, sw

%  local and global efficiency in the network with a sparsity (i.e. cost) of 0.1.
[eff] = gretna_efficiency(bmatrix); %look at the output, eff

% the area under the Cp, Lp curves (0.05<cost<0.4 with an interval of 0.01)
[auc_sw] = gretna_sw_auc(Rmatrix, 0.05,0.4,0.01,0);

% the area under the local and global efficiency curves (0.05<cost<0.4 with
% an interval of 0.01) 
[auc_efficiency] = gretna_efficiency_auc(Rmatrix, 0.05,0.4,0.01,0);




