
% Example: small-world analysis using cortical thickness measurements.
% Yong HE, BIC, MNI, 10/25/2006

%***********************************************************
% enter matlab window

mkdir /data/aces/aces1/yonghe/test
cd /data/aces/aces1/yonghe/test
matlab -nodisplay

% *********************************************************





clear all
warning off

%--------------------------------------------------------------------------
% add the mona functions into the search path.
addpath('/data/aces/aces1/yonghe/mona')

%--------------------------------------------------------------------------
% set the cortical thickness files (e.g. native and 30 smooth kernal)
isnative = 1; % 1: native;

% fwhm=0.0;no smmoth; if fwhm=10, indicating 10 mm smooth kernal;
%Please examine your thickness file to determine the fwhm;
fwhm = 5;


%--------------------------------------------------------------------------
%set your directory of cortical thickness files (set them by yourself !!)

% First, you should establish a subID1 file that includes ID number of each
% subject in this group. Look at the example of subID1 file
% /data/aces/aces1/yonghe/mona/subID1
sourcedir = '/data/aces/aces1/yonghe/cuba/output/';
IDfile ='/data/aces/aces1/yonghe/cuba/analysis/cuba_sub20_id.txt';
thicknessdir = '/thickness/';
surfacedir = '/segment/';
prefix = 'MC000';


%--------------------------------------------------------------------------
%read cortical thickness files of each subject
[vertex_ct_matrix_left,vertex_ct_matrix_right] = mona_readthickness2(sourcedir, IDfile, thicknessdir, prefix, isnative, fwhm);

%read ANIMAL (cortical parcellation) files of each subject
%obtain the vertex labels of the left and right hemisphere (Fig.1 B)
[animal_matrix_left,animal_matrix_right] = mona_readanimalmidsurf2(sourcedir, IDfile, surfacedir, prefix);
[vertex_label_left, vertex_label_right]= mona_surfaceseg (animal_matrix_left,animal_matrix_right);

%raw regional cortical thickness values for reach subject
[regional_thickness] = mona_regionalthickness (vertex_ct_matrix_left, vertex_label_left, vertex_ct_matrix_right, vertex_label_right);

save regional_thickness.txt regional_thickness -ascii
csvwrite('vertex_label_left.txt', vertex_label_left)
csvwrite('vertex_label_right.txt', vertex_label_right)

%please examine the label file (parcellation result) using brain-view
% brain-view subj_001_mid_surface_left_81920.obj vertex_label_left.txt
% brain-view subj_001_mid_surface_right_81920.obj vertex_label_right.txt



clear all
% -------------------------------------------------------------------------
% 1. calculating small-world properties for each group
% -------------------------------------------------------------------------

% removing no interest covariates (e.g. age, gender or mean overall
% thickness) using regression analysis. The resulting residuals can be used
% to substitute for raw regional thickness values. Here we just removed
% mean overall thickness. If you want to remove the effects of age and gender,
% please change Group1_cov_1 and Group2_cov_2. It should be like this:
%cov = [gender age gender-age averageoverll_thickness];

clear
load regional_thickness.txt

% age: n*1; gender: n*1; (n: the number of subjects)
% Group_cov = [mean(regional_thickness,2) age gender];
cov = [mean(regional_thickness,2)];
[reg_ct_resid] = mona_rawtoresid(regional_thickness, cov);

% pearson correlation matrix
sw.Rmatrix = corrcoef(reg_ct_resid);

% small-world parameters in the network with a sparsity of 0.1.
% [bmatrix,r] = mona_R2b(sw.Rmatrix, 's',0.1);
% [N, K, aveden, degree, sw01] = mona_sw_harmonic(bmatrix,1,1000);

%small-world network parameters as a function of sparisty [5%-40%]
s1 = 0.05; s2 = 0.8; deltas = 0.01;
myspar = s1:deltas:s2
for i =1:length(myspar)
    i
    [bmatrix,r] = mona_R2b(corrcoef(reg_ct_resid), 's',myspar(i));
    [N, K, aveden, degree, sw1] = mona_sw_harmonic(bmatrix,1,100);
    sw.Gamma(i) = sw1.Gamma;
    sw.Lambda(i) = sw1.Lambda;
    sw.Sigma(i) = sw1.Sigma;
    sw.Cp(i) = sw1.Cp;
    sw.Lp(i) = sw1.Lp;
end
sw.spar = myspar;



%small-world properties
subplot(1,2,1)
plot(sw.spar,sw.Gamma,'g',sw.myspar,sw.Lambda,'r',sw.myspar,sw.Sigma,'c')
% hold on; plot([myspar(1) myspar(1)], [0, 5],'k')
xlabel('Sparsity (%)');
% text(myspar(1),0.6,'\rightarrow','HorizontalAlignment','left', 'color','k','FontSize',15)
axis([0 45 0 5.5])



load labels.txt
labels_name = {'SFG.R','SFG.L','MFG.R','MFG.L','IFG.R','IFG.L','MdFG.R','MdFG.L','PrCG.R','PrCG.L','LOFG.R','LOFG.L','MOFG.R','MOFG.L',...
    'SPL.R','SPL.L','SMG.R','SMG.L','ANG.R','ANG.L','PCU.R','PCU.L','PoCG.R','PoCG.L',...
    'STG.R','STG.L','MTG.R','MTG.L','ITG.R','ITG.L','UNC.R','UNC.L','MOTG.R','MOTG.L','LOTG.R','LOTG.L','PHG.R','PHG.L',...
    'OP.R','OP.L','SOG.R','SOG.L','MOG.R','MOG.L','IOG.R','IOG.L','CUN.R','CUN.L','LING.R','LING.L',...
    'CING.R','CING.L','INS.R','INS.L'}';



