function [node_betweeness edge_betweeness] = gretna_betweeness(AIJ,brand)
% input:
%   AIJ: n*n symmetric unweighted matrix.
%   brand:0; no random networks; 1; random networks
%
% output:
% node_betweeness.cen: real nodal betweeness
%
% node_betweeness.ncen: normalized nodal betweeness: bi/<b>.%  <b>represents the average
% betweenness for the network.
%
% node_betweeness.zncen: z score of the normalized nodal betweeness in comparison to
% random networks.
%
% edge_betweeness.cenE: real edge betweeness
% edge_betweeness.ncenE; normalized edge betweeness.
%
%
%
%  [node_betweeness edge_betweeness] = gretna_betweeness(AIJ,brand);
%
%Yong HE

warning off


if nargin < 1
    error('No parameters');end

if nargin == 1
    brand = 0; end

if nargin > 2
    error('The number of parameters:<2'); end

x=sparse(AIJ);
m= length(AIJ);

[tmp tmpE]=betweenness_centrality(x,'unweighted');
node_betweeness.cen = tmp/2;
node_betweeness.ncen = node_betweeness.cen/mean(node_betweeness.cen);
edge_betweeness.cenE = full( tmpE);
ave_edge_betweeness = (sum(sum(edge_betweeness.cenE))/2)/ (sum(sum(AIJ))/2);
edge_betweeness.ncenE = edge_betweeness.cenE/ave_edge_betweeness;

if brand == 1;
    n=1000;
    for i=1: n
        i
        srand = gretna_sym_generate_srand(AIJ);
        y=sparse(srand);
        [rtmp rtmpE]=betweenness_centrality(y,'unweighted');
        rcen = rtmp/2;
        nrcen(:,i) = rcen/mean(rcen);
    end

    meanrcen = mean(nrcen,2);
    stdrcen = std(nrcen')';
    node_betweeness.zncen = (node_betweeness.ncen-meanrcen)./stdrcen;
end


