function [Zscore, Pvalue] = gretna_corrcoeffdiff(R1, R2, N1,N2)
% *************************************************************************
% This function is used to calculate the differences between the two
% correlation coefficients.
%
% function [Zscore, Pvalue] = gretna_corrcoeff(Rmatrix1, Rmatrix2, N1,N2)
%
% input:
%           R1,R2:   
%                  two correlation matrice with m*n, respectively%
%           N1, N2:
%                   the sample size of R1, R2.
% 
% output:
%         Zscore: z score
%         Pvalue.onetailed:
%                   P value (one-tailed);
%         Pvalue.twotailed:
%                   P value (two-tailed);
% 
% For example: 
% 
% Example 1:
% R1 = [0.7];
% R2 = [0.2];
% N1 = 97; N2 = 92;
% [Zscore Pvalue ] = gretna_corrcoeffdiff(R1,R2,N1,N2);
%   
% Example 2:
% R1 = [1 0.5 0.3; 0.5 1 0.2; 0.3 0.2 0.8];
% R2 = [1 -0.5 0.23; -0.5 1 0.21; 0.23 0.21 0.1];
% N1 = 97; N2 = 92;
% [Zscore Pvalue ] = gretna_corrcoeffdiff(R1,R2,N1,N2);
% 
% Yong HE, BIC, MNI, McGill 2007/05/01
% *************************************************************************

 
z1 = 0.5 *log((1+R1)./(1-R1))
z2 = 0.5 *log((1+R2)./(1-R2))

Zscore = (z1-z2)/sqrt(1/(N1-3) + 1/(N2-3));
Pvalue.onetailed = 1 - spm_Ncdf(abs(Zscore));
Pvalue.twotailed = 2*Pvalue.onetailed;

