function [A, alpha, kc]= gretna_degdistributionfit(deg);

% *************************************************************************
% function [A, alpha, kc]= gretna_degdistributionfit(deg);
% input:
%       deg: connectivity degree of each node. n*1, n is the number of
%       regions.
% output:
%       A: 
%       alpha:
%       kc:
%  P(k)~A*k^(-1+alpha)* exp(-k/kc)
% 
% Yong HE, BIC, MNI, McGill 2006/08/01
% *************************************************************************

%degree distribution
maxdeg = max(deg);
[origdegpdf,origdegind]= hist(deg, 1:maxdeg);
degind = origdegind(find(origdegpdf));
degpdf = origdegpdf(find(origdegpdf));

N = length(degind);

for i = 1:N
    ydata(i,1) = length(find(deg>=degind(i)));
end
ydata = ydata/ydata(1);
xdata = degind';
 
f_truncated = @(x_truncated,xdata)x_truncated(1)*(xdata.^(-1+x_truncated(2))).*exp(-1*xdata/x_truncated(3)),'xpara','xdata';
[x_truncated norsum resid]= lsqcurvefit(f_truncated,[1 1 3],xdata,ydata);
fitx = (1:1:max(deg)+ 5);
fity_truncated = x_truncated(1)*(fitx.^(-1+x_truncated(2))).*exp(-1*fitx/x_truncated(3));
A = x_truncated(1);
alpha = x_truncated(2);
kc = x_truncated(3);

plot(log(xdata),log(ydata),'k+','MarkerSize',4)
xlabel('log(degree)')
ylabel('log(cumulative distribution)')
hold on;plot(log(fitx),log(fity_truncated),'-k')
 


 