function [Lp S  fraction] = gretna_errortarget(AIJ, type)
%**************************************************************************
% function [Lp S  fraction] = gretna_errortarget(AIJ, type) input:
%       AIJ: a binarized connection matrix type: the mode of removing node
%               1 or 'random': random removing node 2 or 'target': removing
%               the most connected node one by one
% output:
%      S:  the relative size of the largest cluster, S (i.e. the fraction
%           of nodes contained in the largest cluster)
%     Lp:  its average path length, ?6?1, as an increasing number of nodes are
%            randomly ('random') or target ('target') removed fraction: the
%            probability of nodes removed.
%
% He Yong, BIC, MNI, McGill 2006/09/03
%**************************************************************************



if type ==1 | strmatch('error',type) ==1
    mode = 1;
    disp('randomly removing nodes');end

if type ==2 | strmatch('target',type) ==1
    mode = 2;
    disp('target removing nodes');end

AIJ = AIJ - diag(diag(AIJ));

[N, K,   degree, sw] =gretna_sw_harmonic(AIJ,0);
Lp1 = sw.Lp;

% random error
if mode == 1
    for i=1:100
        i
        rankindex = randperm(N);
        for m = 1:N-10
            corrmatrix1 = AIJ;
            corrmatrix1(rankindex(1:m),:) = [];
            corrmatrix1(:,rankindex(1:m)) = [];
            [N1, K1,  degree1, sw2] =gretna_sw_harmonic(corrmatrix1,0);
            Lpp(m) = sw2.Lp;
            fraction(m) = m/N;
            sum(sum(corrmatrix1))
            [lcs]=gretna_lcs( corrmatrix1);
            largestCompN(m) = lcs;
        end
        LL(i,:) = Lpp;
        SS (i,:) = largestCompN/N;
    end
    S = mean(SS);
    Lp = mean(LL);
end

% [rankdeg rankindex]=sort(degree.deg,'descend');
[node_betweeness edge_betweeness] = gretna_betweeness(AIJ,0);
[rankdeg rankindex]=sort(node_betweeness.ncen,'descend');


%target attack
if mode == 2
    for m = 1:N-10
         
        corrmatrix1 = AIJ;
        corrmatrix1(rankindex(1:m),:) = [];
        corrmatrix1(:,rankindex(1:m)) = [];
        [N1, K1,   degree1, sw2] = gretna_sw_harmonic(corrmatrix1,0);
        Lp(m) = sw2.Lp;
        fraction(m) = m/N;
        [lcs]=gretna_lcs( corrmatrix1);
        largestCompN(m) = lcs;
    end
    S = largestCompN/N;
end

Lp = [Lp1 Lp];
S = [1 S];
fraction = [0 fraction];




