


clear all

addpath('/data/aces/aces1/yonghe/gretna')

%**************************************************************************
%  calculate local and global efficiency of structural cortical 
%  networks using cortical thickness measurements (group 1)
%**************************************************************************

%read cortical thickness files of each subject
input_Group1_ct_left = 'Group1_subject_filename_ct_left.txt';
input_Group1_ct_right = 'Group1_subject_filename_ct_right.txt';
[M_left, M_right] = gretna_readthickness(input_Group1_ct_left,   input_Group1_ct_right);

%read ANIMAL (cortical parcellation) files of each subject
input_Group1_ANIMAL_left = 'Group1_subject_filename_ANIMAL_Labels_left.txt';
input_Group1_ANIMAL_right = 'Group1_subject_filename_ANIMAL_Labels_right.txt';
[vertex_label_left, vertex_label_right] = gretna_surfaceseg(input_Group1_ANIMAL_left, input_Group1_ANIMAL_right);
% if you want to visulize the ANIMAL parcellation using brain-view
% software, please try....
% csvwrite('vertex_label_left.txt', vertex_label_left)
% csvwrite('vertex_label_right.txt', vertex_label_right)
% brain-view vertex_label_left.txt XXXXXX_mid_surface_left_81920.obj
% brain-view vertex_label_right.txt XXXXXX_mid_surface_left_81920.obj

%raw regional cortical thickness values for reach subject
[regional_thickness] = gretna_regionalthickness (M_left, vertex_label_left, M_right, vertex_label_right);


% removing no interest covariates (e.g. age, gender or mean overall
% thickness) using regression analysis. The resulting residuals can be used
% to substitute for raw regional thickness values. Here we just removed
% mean overall thickness. If you want to remove the effects of age and
% gender, please change Group1_cov_1. It should be like this: 
% cov = [gender age gender-age averageoverll_thickness]; 
% age: n*1; gender: n*1; (n: the number of subjects)
% Group_cov = [mean(regional_thickness,2) age gender];

cov = [mean(regional_thickness,2)];
[regional_thickness_resid] = gretna_rawtoresid(regional_thickness, cov);

% calculating pearson correlation matrix
Rmatrix = corrcoef(regional_thickness_resid);

% thresholding the correlation matrix into a binarized matrix at a sparsity
% (i.e. wiring cost) of 0.1 (you can choose a sparsity of 0.05~0.5)
sparsity = 0.1;
[bmatrix,r] = gretna_R2b(Rmatrix, 's', sparsity);

% small-world parameters (Cp,Lp, Gamma, Lambda, Sigma) in the network with
% a sparsity (i.e. cost) of 0.1. 
[N, K, degree, sw] = gretna_sw_harmonic(bmatrix); %look at the output, sw

%  local and global efficiency in the network with a sparsity (i.e. cost) of 0.1.
[eff] = gretna_efficiency(bmatrix); %look at the output, eff

% the area under the Cp, Lp curves (0.05<cost<0.4 with an interval of 0.01)
[auc_sw] = gretna_sw_auc(Rmatrix, 0.05,0.4,0.01,0);

% the area under the local and global efficiency curves (0.05<cost<0.4 with
% an interval of 0.01) 
[auc_efficiency] = gretna_efficiency_auc(Rmatrix, 0.05,0.4,0.01,0);




