function [regional_thickness_resid] = gretna_rawtoresid(regional_thickness, cov_1)

% *************************************************************************
% This function is used to calculate residuals of cortical thickness of
% each region after removing the effects from some covariates, such as
% gender, age, gender-age interaction and overall cortical thickness, using
% regression analysis.
%
%  function [regional_thickness_resid] =...
%               gretna_rawtoresid(regional_thickness, cov_1)
%
% input:
%       regional_thickness:
%               s*N matrix. s: the number of subjects; N: the number of
%               regions (e.g. 54)
%       cov1:
%               s*m matrix. s: the number of subjects; m: the number of no
%               interest covariates; for example: [gender age
%               gender-age_interaction average_overall_thickness]; gender:
%               s*1 vector; age: s*1 vector...
%
% output:
%       regional_thickness_resid: 
%               the residuals of cortical thickness of each region after
%               removing the effects of covariates. s*N matrix. s: the
%               number of subjects; N: the number of regions.
% 
% Yong HE, BIC, MNI, McGill, 2006/09/12
% *************************************************************************


if nargin < 1
    error('No parameters');end

if nargin == 2
    cov2 = []; end

if nargin > 3
    error('Error the number of input parameters (< 6).');
end

NR = size(regional_thickness,2);
N = size(regional_thickness,1);
N1= size(cov_1,1);

if N~=N1
    error('Error the number of subjects between regional_thickness and covariates!');
end

desm  = [ones(N,1) cov_1];
for i = 1:NR
   
    resp = regional_thickness(:,i);
    [B,BINT,R] = regress(resp,desm);
    regional_thickness_resid (:,i) = R;
end


