function [vertex_animalmidsurf_matrix] = gretna_readanimalmidsurf1(sourcedir, IDfile, surfacedir, prefix)

% *************************************************************************
% This function is used to read animal mid cortical surface (ANIMAL +
% INSECT) typically obtained from a BIC pipeline procedure.
%
%function [vertex_animalmidsurf_matrix] = gretna_readanimalmidsurf(sourcedir,
%           IDfile, surfacedir, prefix)
%
% For example: sourcedir =
% '/data/aces/aces1/yonghe/eld_mci/pipe1004/outputmci/'; IDfile: 'IDfile'.
% Here "IDfile" is the ID number of each subject. It
%           should be is a txt file including the ID of each subject.
% surfacedir = '/seg/'; prefix = 'mci'; [vertex_animalmidsurf_matrix] =
% gretna_readanimalmidsurf(sourcedir, IDfile,
%           surfacedir, prefix)
%
%
% /data/aces/aces1/yonghe/eld_mci/pipe1004/outputmci/01/seg/
% mci_01_animal_midsurf_81920.txt
%
% /data/aces/aces1/yonghe/eld_mci/pipe1004/outputmci/02/seg/
% mci_02_animal_midsurf_81920.txt ......
%
% input:
%           sourcedir:  the directory of each subject. e.g.
%                           /data/aces/aces1/yonghe/eld_mci/pipe1004/output
%                           mci/;
%           subID:      a txt file including the ID of each subject. It
%                          should be the name of subdirectory under the
%                          input parameter "sourcedir". If you open this
%                          txt file. It should be like this: 01 02 03 04...
%                          or like this:
%                           01 02 03 04 ...
%           surfacedir: the directory saving the anaimal_midsurface
%                          for each subject. It should be "/seg/"
%           prefix:      the prefix name of animal midsurface file. e.g.
%                          in the filename "mci_01_animal_midsuf_81920.txt'
%                          ,  prefix = 'mci';
%
% output:
%           vertex_animalmidsurf_matrix: an s*n matrix with animal
%                     midsurface values for each node for each subject. n:
%                     the number of nodes (e.g. 40962); s: the number of
%                     subjects.
%
% Yong HE, BIC, MNI, McGill 2006/09/12
%

if nargin ~= 4
    error('No parameters');end

if ~strcmp(surfacedir, '\seg\')
    error('Error "surfacedir" parameter');
end

subID = textread(IDfile, '%s');
Nsub = size(subID,1);

for i = 1:Nsub
    filename1 = strcat(strcat(strcat(prefix,'_'),subID{i}),'_animal_midsurf_81920.txt');
    filename2 = strcat(strcat(sourcedir,subID{i}),surfacedir);
    filename = strcat(filename2,filename1);
    vertex_animalmidsurf_matrix(i,:) = load(filename)';
end
