function [regional_thickness] = gretna_regionalthickness_78AAL_jc(M_left, vertex_label_left, M_right, vertex_label_right)

% *************************************************************************
% This function is used to calcluate average cortical thickness within
% regions for each subject based on a labelled surface file (i.e.
% vertex_label)
%
% function [regional_thickness] = ...
%               gretna_regionalthickness(M_left, vertex_label_left, M_right,
%               vertex_label_right)
%
% For example:
%       M_left, M_right: s*n matrix (cortical thickness).
%       vertex_label_left, vertex_label_right: n*1 matrix; (animal
%       parcellation)
%
% [regional_thickness] = ...
%               gretna_regionalthickness(M_left, vertex_label_left, M_right,
%               vertex_label_right)
%
% input:
%           M_left:  thickness values( s*n matrix). n: the number of nodes
%                       (vertex); s: the number of subjects.
%           vertex_label_left: the label of each vertex. (left hemisphere)
%           M_right:  thickness values( s*n matrix). n: the number of nodes
%                       (vertex); s: the number of subjects.
%           vertex_label_right: the label of each vertex. (right
%           hemisphere)
%
% output:
%           regional_thickness: averaged cortical thickness values for each
%                      region of each subject (s*N matrix).  N: the number
%                      of regions (54); s: the number of subjects.
%
%
% Yong HE, BIC, MNI, McGill 2006/09/12
% *************************************************************************


if nargin < 1
    error('No parameters');end

if nargin > 5
    error('Error the number of input parameters (< 6).');
end

% labelpath = '/data/aces/aces1/yonghe/gretna/labels.txt';
% original_labels = load (labelpath);
original_labels_AAL = [1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,39,40,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,79,80,81,82,83,84,85,86,87,88,89,90;];

M = M_left';

if size(M,1)~=size(vertex_label_left,1)
    error('Error the M and vertex_label.');
end

for i = 1:length(original_labels_AAL)
    regionsct = M(find(vertex_label_left == original_labels_AAL(i)),:);
    for j = 1:size(M,2)
        regional_thickness_left(i,j) = sum(regionsct(:,j))/size(regionsct,1);
    end
end

regional_thickness_left = regional_thickness_left';


M = M_right';
if size(M,1)~=size(vertex_label_right,1)
    error('Error the M and vertex_label.');
end

for i = 1:length(original_labels_AAL)
    regionsct = M(find(vertex_label_right == original_labels_AAL(i)),:);
    for j = 1:size(M,2)
        regional_thickness_right(i,j) = sum(regionsct(:,j))/size(regionsct,1);
    end
end

regional_thickness_right = regional_thickness_right';


regional_thickness =[];
for i=1:41
    regional_thickness = [ regional_thickness [ regional_thickness_left(:,2*i-1) regional_thickness_right(:,2*i)  ]];
end

return




