function [vertex_label_left, vertex_label_right] = gretna_surfaceseg_jc(vertex_animalmidsurf_left, vertex_animalmidsurf_right, Prop)

% *************************************************************************
% This function is used to segment cortical surface (ANIMAL + INSECT)
%
%
% function [vertex_label_left, vertex_label_right] =
% gretna_surfaceseg(subjects_filename_ANIMAL_left, subjects_filename_ANIMAL_right)
%
%
% For example:
%
% ......
%
% input:
%
%
% output:
%           vertex_label_left: a labelled surface file of left hemisphere (.txt)
%           vertex_label_right: a labelled surface file of right hemisphere (.txt)
%
% Yong HE, BIC, MNI, McGill 2007/05/01
% *************************************************************************



warning off

vertex_label_matrix_left = vertex_animalmidsurf_left';
vertex_label_matrix_right = vertex_animalmidsurf_right';

[LeftMax, vertex_label_left] = max(hist(vertex_label_matrix_left', 0:255));
[RightMax, vertex_label_right] = max(hist(vertex_label_matrix_right', 0:255));

vertex_label_left = vertex_label_left - ones(1,length(vertex_label_left));
vertex_label_right = vertex_label_right - ones(1,length(vertex_label_right));

load labels.txt

tleft = ismember(vertex_label_left, labels);
tright = ismember(vertex_label_right, labels);

vertex_label_left = (vertex_label_left .* tleft)';
vertex_label_right = (vertex_label_right .* tright)';

%test

if Prop ~= 0
    S = size(vertex_animalmidsurf_left,1);
    LeftMaxC = LeftMax / S;
    RightMaxC = RightMax / S;

    vertex_label_left(find(LeftMaxC<Prop)) = 0;
    vertex_label_right(find(RightMaxC<Prop)) = 0;
end
fprintf('Finished.\n')

return;
