
function [auc] = gretna_sw_auc(Rmatrix, s1,s2,deltas,type)

% function [auc] = gretna_sw_auc(Rmatrix, s1,s2,deltas,type)
%   input:  
%       Rmatrix: correlation matrix;
%       s1: sparsity1: e.g. 0.05
%       s2: sparsity2: e.g. 0.40
%       deltas: the interval: e.g. 0.01
%       type: 0: no random networks;
%               1: generating 100 random networks to calucate Gamma and
%               Lambda
% 
%   output: 
%       auc: the area under the Cp and Lp curves from sparsity, s1 to
%       sparsity, s2.  
%
% example:
%  1. the area under the Cp,Lp curves
%    [auc] = gretna_sw_auc(Rmatrix, 0.05,0.4,0.01,0)
%   
%  2. the area under the Cp,Lp,Gamma, Lambda, Sigma curves
%   [auc] = gretna_sw_auc(Rmatrix, 0.05,0.4,0.01,1)
% 
%  Yong HE, BIC, MNI, McGill 2007/05/01
% *************************************************************************



thresh_s = s1:deltas:s2;

auc.thresh_s = thresh_s;

if type == 0 %Cp Lp
    for j =1:length(thresh_s)
        [bmatrix,r] = gretna_R2b(Rmatrix, 's',thresh_s(j));
        [N, K, degree, sw] = gretna_sw_harmonic(bmatrix,0,0);
        Cp(j) = sw.Cp;
        Lp(j) = sw.Lp;
    end
    auc.aCp =  (sum(Cp) -  sum(Cp([1 end]))/2)*deltas;
    auc.aLp =  (sum(Lp) -  sum(Lp([1 end]))/2)*deltas;
    auc.Cp = Cp;
    auc.Lp = Lp;
end


if type == 1 %Cp Lp, gamma,lambda, sigma
    for j =1:length(thresh_s)
        [bmatrix,r] = gretna_R2b(Rmatrix, 's',thresh_s(j));
        [N, K, degree, sw] = gretna_sw_harmonic(bmatrix,2,100);
        Cp(j) = sw.Cp;
        Lp(j) = sw.Lp;
        Gamma(j) = sw.Gamma;
        Lambda(j) = sw.Lambda;
        Sigma(j) = sw.Sigma;
    end
    auc.aCp =  (sum(Cp) -  sum(Cp([1 end]))/2)*deltas;
    auc.aLp =  (sum(Lp) -  sum(Lp([1 end]))/2)*deltas;
    auc.aGamma =  (sum(Gamma) -  sum(Gamma([1 end]))/2)*deltas;
    auc.aLambda =  (sum(Lambda) -  sum(Lambda([1 end]))/2)*deltas;
    auc.aSigma =  (sum(Sigma) -  sum(Sigma([1 end]))/2)*deltas;
    auc.Cp = Cp;
    auc.Lp = Lp;
    auc.Gamma = Gamma;
    auc.Lambda = Lambda;
    auc.Sigma = Sigma
end