%function [A, alpha, kc]= mona_degreedistribution(deg);
function [A, xdata,ydata]= mona_degreedistribution(deg);

% *************************************************************************
% function [A, alpha, kc]= mona_degreedistribution(deg);
% input:
%       deg: connectivity degree of each node. n*1, n is the number of
%       regions.
% output:
%       A: 
%       alpha:
%       kc:
%  P(k)~A*k^(-1+alpha)* exp(-k/kc)
% 
% Yong HE, BIC, MNI, McGill 2006/08/01
% *************************************************************************

%degree distribution
[x_icdf x_cdf x_pdf x_xaxis] = fmri_icpdf(deg);
%fit
xdata = x_xaxis(1:end-1);
ydata = x_icdf(1:end-1);
f_truncated = @(x_truncated,xdata)x_truncated(1)*(xdata.^(-1+x_truncated(2))).*exp(-1*xdata/x_truncated(3)),'xpara','xdata';
[x_truncated norsum resid]= lsqcurvefit(f_truncated,[1 1 1],xdata,ydata)
fitx = (0:1:max(deg)+5);
fity_truncated = x_truncated(1)*(fitx.^(-1+x_truncated(2))).*exp(-1*fitx/x_truncated(3));
A = x_truncated(1);
alpha = x_truncated(2);
kc = x_truncated(3);

plot(log(xdata),log(ydata),'k+','MarkerSize',4)
xlabel('log(degree)')
ylabel('log(cumulative distribution)')
hold on;plot(log(fitx),log(fity_truncated),'-k')
 



function [x_icdf, x_cdf, x_pdf, x_xaxis] = fmri_icpdf(x);
y = x;
N = length(y);
miny = min(y);
maxy = max(y);
tmpy = 1;

%pdf: P{K=k}
while min(y) ~=max(y)
    minindex = find(y == min(y));
    x_pdf (tmpy) = length(minindex)/N;
    x_xaxis(tmpy) = min(y);
    y(minindex) = maxy;
    tmpy = tmpy + 1;
end

if miny == maxy
    x_pdf = 1;
    x_xaxis = max(x);
else
    x_pdf(end+1) = length(find(x ==max(x)))/N;
    x_xaxis(end+1) = max(x);
end

% cdf: P{K<=k}
x_cdf(1) = x_pdf(1);
for i = 2:length(x_xaxis)
    x_cdf(i) = x_cdf(i-1) + x_pdf(i);
end

%icdf: P{K>k}
x_icdf = 1 - x_cdf;
return;