function [Lp S  fraction] = mona_errortarget(AIJ, type)
%**************************************************************************
% function [Lp S  fraction] = mona_errortarget(AIJ, type) input: 
%       AIJ: a binarized connection matrix type: the mode of removing node
%               1 or 'random': random removing node 2 or 'target': removing
%               the most connected node one by one
% output:
%      S:  the relative size of the largest cluster, S (i.e. the fraction
%           of nodes contained in the largest cluster) 
%     Lp:  its average path length, 61, as an increasing number of nodes are
%            randomly ('random') or target ('target') removed fraction: the
%            probability of nodes removed.
% 
% He Yong, BIC, MNI, McGill 2006/09/03
%**************************************************************************



if type ==1 | strmatch('error',type) ==1
    mode = 1;
    disp('randomly removing nodes');end

if type ==2 | strmatch('target',type) ==1
    mode = 2;
    disp('target removing nodes');end

AIJ = AIJ - diag(diag(AIJ));

[N, K, aveden, degree, sw] =mona_sw(AIJ,0);
BIJ = sw.BIJ;
Lp1 = sw.Lp;



% random error
if mode == 1
    rankindex = randperm(N);
    for m = 1:N-2
        corrmatrix1 = BIJ;
        corrmatrix1(rankindex(1:m),:) = [];
        corrmatrix1(:,rankindex(1:m)) = []; 
        [N1, K1,  aveden1, degree1, sw1] =mona_sw(corrmatrix1,0);
        Lp(m) = sw1.Lp;
        fraction(m) = m/N;
        largestCompN(m) = sw1.LargestCompSize;
    end
    S = largestCompN/N;
    
end

[rankdeg rankindex]=sort(degree.deg,'descend');
%target attack
if mode == 2
    for m = 1:N-2
        corrmatrix1 = BIJ;
        corrmatrix1(rankindex(1:m),:) = [];
        corrmatrix1(:,rankindex(1:m)) = []; 
        [N2, K2,  aveden2, degree2, sw2] = mona_sw(corrmatrix1,0);
        Lp(m) = sw2.Lp;
        fraction(m) = m/N;
        largestCompN(m) = sw2.LargestCompSize;
    end
    S = largestCompN/N;
end
     
Lp = [Lp1 Lp];
S = [1 S];
fraction = [0 fraction];

        
        
        
        