function [vertex_label_left, vertex_label_right] = mona_surfaceseg_test(vertex_midsurf_left, vertex_midsurf_right, Template,T)

% *************************************************************************
% This function is used to segment cortical surface (ANIMAL + INSECT)
% 
% 
% function [vertex_label] =
%               mona_surfaceseg(vertex_animalmidsurf_left,vertex_animalmids
%               urf_right)
%
%     
% For example:
% 
% ......
% 
% input: 
%           
% 
% output:
%           vertex_label_left: a labelled surface file of left hemisphere (.txt)
%           vertex_label_right: a labelled surface file of right hemisphere (.txt)
% 
% Yong HE, BIC, MNI, McGill 2007/05/01
% *************************************************************************

if nargin <1
    error('No parameters');end

%vertex_label_matrix_left = vertex_midsurf_left';
%vertex_label_matrix_right = vertex_midsurf_right';

[LeftMax, vertex_label_left] = max(hist(vertex_midsurf_left, 0:255));
[RightMax, vertex_label_right] = max(hist(vertex_midsurf_right, 0:255));

vertex_label_left = vertex_label_left - ones(1,length(vertex_label_left));
vertex_label_right = vertex_label_right - ones(1,length(vertex_label_right));

if strcmp(Template, 'animal') == 1
    labels = load ('labels_ICBM56_surface.txt');
elseif strcmp(Template, 'AAL') == 1
    labels = load ('labels_AAL82_surface.txt');
else error ('No template found');end
    
tleft = ismember(vertex_label_left, labels);
tright = ismember(vertex_label_right, labels);

vertex_label_left = (vertex_label_left .* tleft)';
vertex_label_right = (vertex_label_right .* tright)'; 

%test
S = size(vertex_midsurf_left,1);
LeftMaxC = LeftMax / S;
RightMaxC = RightMax / S;

vertex_label_left(find(LeftMaxC<T)) = 0;
vertex_label_right(find(RightMaxC<T)) = 0;

%or
%vertex_label_left = LeftMaxC;
%vertex_label_right = RightMaxC;

fprintf('-------------Finished surface label.\n')

return;
